pytilities.types._numbertypemeta._NumberTypeMeta

Package pytilities :: Package types :: Module _numbertypemeta :: Class _NumberTypeMeta |
[hide private]
[frames] | no frames]

# Type _NumberTypeMeta

source code

    object --+
             |
          type --+
                 |
                _NumberTypeMeta

Instance Methods | [hide private]
__instancecheck__(self, instance) | source code
__subclasscheck__(self, subclass) | source code
Inherited from `type`: `__call__`, `__delattr__`, `__eq__`, `__ge__`, `__getattribute__`, `__gt__`, `__hash__`, `__init__`, `__le__`, `__lt__`, `__ne__`, `__new__`, `__repr__`, `__setattr__`, `__subclasses__`, `mro` Inherited from `object`: `__format__`, `__reduce__`, `__reduce_ex__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `type`: `__abstractmethods__`, `__base__`, `__bases__`, `__basicsize__`, `__dictoffset__`, `__flags__`, `__itemsize__`, `__mro__`, `__name__`, `__weakrefoffset__` Inherited from `object`: `__class__`

Method Details | [hide private]

### __instancecheck__(self, instance) | source code
Overrides: __instancecheck__

### __subclasscheck__(self, subclass) | source code
Overrides: __subclasscheck__